==> nextcloud-app-deck-1:1.8.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/uk.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Ви створили нову дошку {board}",
    "{user} has created a new board {board}" : "{user} створив нову дошку {board}",
    "You have deleted the board {board}" : "Ви вилучили дошку {board}",
    "{user} has deleted the board {board}" : "{user} вилучив дошку {board}",
    "You have restored the board {board}" : "Ви відновили дошку {board}",
    "{user} has restored the board {board}" : "{user} відновив дошку {board}",
    "You have shared the board {board} with {acl}" : "Ви поділилися дошкою {board} з {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} поділився дошкою {board} з {acl}",
    "You have removed {acl} from the board {board}" : "Ви вилучили {acl} з дошки {board}",
    "{user} has removed {acl} from the board {board}" : "{user} вилучив {acl} з дошки {board}",
    "You have renamed the board {before} to {board}" : "Ви перейменували дошку з {before} у {board}",
    "Deck" : "Колода",
    "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
    "Load more" : "Більше",
    "Personal" : "Особисте",
    "Finished" : "Завершено",
    "To review" : "На перегляд",
    "Action needed" : "Потребує дій",
    "Later" : "Пізніше",
    "copy" : "копіювати",
    "To do" : "Заплановано",
    "Doing" : "Виконується",
    "Done" : "Готово",
    "Example Task 3" : "Приклад завдання 3",
    "Example Task 2" : "Приклад завдання 2",
    "Example Task 1" : "Приклад завдання 1",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "The file was only partially uploaded" : "Файл завантажено лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутня тека для тимчасових файлів",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "No file uploaded or file size exceeds maximum of %s" : "Немає завантажених файлів або розмір файлу перевищує максимум %s",
    "Card not found" : "Картку не знайдено",
    "Invalid date, date format must be YYYY-MM-DD" : "Недійсна дата, формат дати має бути РРРР-ММ-ДД",
    "Card details" : "Деталі картки",
    "Add board" : "Додати дошку",
    "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
    "Search by board title" : "Шукати за назвою дошки",
    "Select board" : "Вибрати дошку",
    "Select a board" : "Вибрати дошку",
    "Select a list" : "Виберіть список",
    "Cancel" : "Скасувати",
    "Close" : "закрити",
    "Select a card" : "Вибрати картку",
    "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
    "Link to card" : "Прив'язати до картки",
    "File already exists" : "Файл вже існує",
    "A file with the name {filename} already exists." : "Файл {filename} вже існує.",
    "Do you want to overwrite it?" : "Дійсно перезаписати файл?",
    "Overwrite file" : "Перезаписати файл",
    "Keep existing file" : "Зберегти поточний файл",
    "This board is read only" : "Дошка тільки для читання",
    "Drop your files to upload" : "Пересуньте файли сюди для завантаження",
    "Add card" : "Додати картку",
    "Archived cards" : "Архівні картки",
    "Add list" : "Додати список",
    "List name" : "Назва списку",
    "Apply filter" : "Відфільтрувати",
    "Filter by tag" : "Відібрати за позначками",
    "Filter by assigned user" : "Відібрати за призначеним користувачем",
    "Unassigned" : "Скасовано призначення",
    "Filter by due date" : "Відібрати за датою завершення",
    "Overdue" : "Протерміновано",
    "Next 7 days" : "Наступні 7 днів",
    "Next 30 days" : "Наступні 30 днів",
    "No due date" : "Без дати завершення",
    "Clear filter" : "Очистити фільтр",
    "Hide archived cards" : "Приховати архівні картки",
    "Show archived cards" : "Показати архівні картки",
    "Toggle compact mode" : "Перемкнути компактний вигляд",
    "Details" : "Деталі",
    "Loading board" : "Завантаження дошки",
    "Board not found" : "Дошку не знайдено",
    "Sharing" : "Поділитись",
    "Tags" : "Теги",
    "Deleted items" : "Вилучені елементи",
    "Timeline" : "Дії",
    "Deleted lists" : "Вилучені списки",
    "Undo" : "Скасувати",
    "Deleted cards" : "Вилучені картки",
    "Share board with a user, group or circle …" : "Поділитися дошкою з користувачем, групою або колом...",
    "Board owner" : "Власник дошки",
    "(Group)" : "(група)",
    "(Circle)" : "(Коло)",
    "Can edit" : "Можна редагувати",
    "Can share" : "Can share",
    "Can manage" : "Може керувати",
    "Owner" : "Власник",
    "Delete" : "Вилучити",
    "Transfer" : "Передати",
    "Add a new list" : "Додати новий список",
    "Delete list" : "Вилучити список",
    "Add a new card" : "Додати нову картку",
    "Edit" : "Редагувати",
    "Add a new tag" : "Додати нову позначку",
    "title and color value must be provided" : "потрібно зазначити назву та колір",
    "Members" : "Учасники",
    "Upload new files" : "Додати файл",
    "Share from Files" : "Відкрити Файли",
    "Add this attachment" : "Долучити вкладення",
    "Download" : "Завантажити",
    "Delete Attachment" : "Забрати вкладення",
    "Restore Attachment" : "Відновити вкладення",
    "File to share" : "Виберіть файл для надання доступу",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Attachments" : "Вкладення",
    "Comments" : "Коментарі",
    "Modified" : "Змінено",
    "Created" : "Створено",
    "Assign a tag to this card…" : "Додати позначку до цієї картки",
    "Assign to users" : "Призначити користувачам",
    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
    "Assign a user to this card…" : "Призначити користувачеві цю картку",
    "Due date" : "Протягом",
    "Set a due date" : "Встановити дату завершення",
    "Remove due date" : "Вилучити до",
    "Select Date" : "Вкажіть дату",
    "Today" : "Сьогодні",
    "Tomorrow" : "Завтра",
    "Next week" : "Наступний тиждень",
    "Next month" : "Наступний місяць",
    "Save" : "Зберегти",
    "In reply to" : "У відповідь",
    "Cancel reply" : "Скасувати відповідь",
    "Reply" : "Відповісти",
    "Update" : "Оновлення",
    "Description" : "Опис",
    "(Unsaved)" : "(Не збережено)",
    "(Saving…)" : "(Зберігання...)",
    "Formatting help" : "Форматування довідки",
    "Edit description" : "Редагувати опис",
    "View description" : "Переглянути опис",
    "Add Attachment" : "Долучити вкладення",
    "Choose attachment" : "Вибрати вкладення",
    "(group)" : "(група)",
    "Assign to me" : "Призначити мені",
    "Move card" : "Пересунути картку",
    "Unarchive card" : "Розархівувати картку",
    "Archive card" : "Архівувати картку",
    "Delete card" : "Вилучити картку",
    "Move card to another board" : "Перемістити картку до іншої дошки",
    "seconds ago" : "секунд тому",
    "All boards" : "Усі дошки",
    "Archived boards" : "Архівні дошки",
    "Shared with you" : "Вам надано доступ",
    "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
    "Board details" : "Деталі дошки",
    "Edit board" : "Редагувати дошку",
    "Clone board" : "Копіювати дошку",
    "Unarchive board" : "Розархівувати дошку",
    "Archive board" : "Архівувати дошку",
    "No notifications" : "Немає сповіщень",
    "Delete board" : "Вилучити дошку",
    "Board {0} deleted" : "Дошку {0} вилучено",
    "An error occurred" : "Виникла помилка",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Ви впевнені, що хочете видалити дошку {title}? Це призведе до видалення всіх даних цієї дошки, включаючи архівні картки.",
    "Delete the board?" : "Вилучити дошку?",
    "Link to a board" : "Прив'язати до дошки",
    "Link to a card" : "Прив'язати до картки",
    "Something went wrong" : "От халепа!",
    "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
    "Share" : "Поділитися",
    "This week" : "Цього тижня"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-deck-1:1.10.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/uk.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Ви створили нову дошку {board}",
    "{user} has created a new board {board}" : "{user} створив нову дошку {board}",
    "You have deleted the board {board}" : "Ви вилучили дошку {board}",
    "{user} has deleted the board {board}" : "{user} вилучив дошку {board}",
    "You have restored the board {board}" : "Ви відновили дошку {board}",
    "{user} has restored the board {board}" : "{user} відновив дошку {board}",
    "You have shared the board {board} with {acl}" : "Ви поділилися дошкою {board} з {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} поділився дошкою {board} з {acl}",
    "You have removed {acl} from the board {board}" : "Ви вилучили {acl} з дошки {board}",
    "{user} has removed {acl} from the board {board}" : "{user} вилучив {acl} з дошки {board}",
    "You have renamed the board {before} to {board}" : "Ви перейменували дошку з {before} на {board}",
    "{user} has renamed the board {before} to {board}" : "{user} змінив(-ла) назву дошки {before} на {board}",
    "You have archived the board {board}" : "Ви заархівували дошку {board}",
    "{user} has archived the board {before}" : "{user} заархівував дошку {before}",
    "You have unarchived the board {board}" : "Ви розархівували дошку {board}",
    "{user} has unarchived the board {before}" : "{user} розархівував дошку {перед}",
    "You have created a new list {stack} on board {board}" : "Ви створили новий список {stack} на борту {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} створив новий список {stack} на дошці {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Ви перейменували список {before} на {stack} на дошці {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} змінив(-ла) назву списку {before} на {stack} на дошці {board}",
    "You have deleted list {stack} on board {board}" : "Ви видалили список {stack} на дошці {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} видалив список {stack} на дошці {board}",
    "You have created card {card} in list {stack} on board {board}" : "Ви створили картку {card} у списку {stack} на дошці {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} створив картку {card} у списку {stack} на дошці {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Ви видалили картку {card} у списку {stack} на дошці {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} видалив картку {card} у списку {stack} на дошці {board}",
    "You have renamed the card {before} to {card}" : "Ви перейменували картку {before} на {card}",
    "{user} has renamed the card {before} to {card}" : "{user} змінив(-ла) назву картки {before} на {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Ви додали опис картки {card} у списку {stack} на дошці {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} додав опис до картки {card} у списку {stack} на дошці {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Ви оновили опис картки {card} у списку {stack} на дошці {board}",
    "Deck" : "Колода",
    "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
    "Upcoming cards" : "Очікують на виконання",
    "Load more" : "Більше",
    "Personal" : "Особисте",
    "Deck board" : "Дошка Deck",
    "%s on %s" : "%s на %s",
    "Finished" : "Завершено",
    "To review" : "На перегляд",
    "Action needed" : "Потребує дій",
    "Later" : "Пізніше",
    "copy" : "копіювати",
    "To do" : "Заплановано",
    "Doing" : "Виконується",
    "Done" : "Готово",
    "Example Task 3" : "Приклад завдання 3",
    "Example Task 2" : "Приклад завдання 2",
    "Example Task 1" : "Приклад завдання 1",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "The file was only partially uploaded" : "Файл завантажено частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній каталог тимчасових файлів",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "No file uploaded or file size exceeds maximum of %s" : "Немає завантажених файлів або розмір файлу перевищує максимум %s",
    "Card not found" : "Картку не знайдено",
    "Invalid date, date format must be YYYY-MM-DD" : "Недійсна дата, формат дати має бути РРРР-ММ-ДД",
    "Add board" : "Додати дошку",
    "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
    "Search by board title" : "Шукати за назвою дошки",
    "Select board" : "Вибрати дошку",
    "Create a new card" : "Створити нову картку",
    "Select a board" : "Вибрати дошку",
    "Select a list" : "Виберіть список",
    "Card title" : "Заголовок картки",
    "Cancel" : "Скасувати",
    "Close" : "закрити",
    "Select a card" : "Вибрати картку",
    "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
    "Link to card" : "Прив'язати до картки",
    "File already exists" : "Файл вже існує",
    "A file with the name {filename} already exists." : "Файл {filename} вже існує.",
    "Do you want to overwrite it?" : "Дійсно перезаписати файл?",
    "Overwrite file" : "Перезаписати файл",
    "Keep existing file" : "Зберегти поточний файл",
    "This board is read only" : "Дошка тільки для читання",
    "Drop your files to upload" : "Пересуньте файли сюди для завантаження",
    "Add card" : "Додати картку",
    "Archived cards" : "Архівні картки",
    "Add list" : "Додати список",
    "List name" : "Назва списку",
    "Apply filter" : "Відфільтрувати",
    "Filter by tag" : "Відібрати за позначками",
    "Filter by assigned user" : "Відібрати за призначеним користувачем",
    "Unassigned" : "Скасовано призначення",
    "Filter by due date" : "Відібрати за датою завершення",
    "Overdue" : "Протерміновано",
    "Next 7 days" : "Наступні 7 днів",
    "Next 30 days" : "Наступні 30 днів",
    "No due date" : "Без дати завершення",
    "Clear filter" : "Очистити фільтр",
    "Hide archived cards" : "Приховати архівні картки",
    "Show archived cards" : "Показати архівні картки",
    "Toggle compact mode" : "Перемкнути компактний вигляд",
    "Details" : "Деталі",
    "Loading board" : "Завантаження дошки",
    "Create a new list to add cards to this board" : "Створіть список щоб додати картки на цю дошку",
    "Board not found" : "Дошку не знайдено",
    "Sharing" : "Поділитися",
    "Tags" : "Теги",
    "Deleted items" : "Вилучені елементи",
    "Timeline" : "Дії",
    "Deleted lists" : "Вилучені списки",
    "Undo" : "Скасувати",
    "Deleted cards" : "Вилучені картки",
    "Share board with a user, group or circle …" : "Поділитися дошкою з користувачем, групою або колом...",
    "Board owner" : "Власник дошки",
    "(Group)" : "(група)",
    "(Circle)" : "(Коло)",
    "Can edit" : "Можна редагувати",
    "Can share" : "Can share",
    "Can manage" : "Може керувати",
    "Owner" : "Власник",
    "Delete" : "Вилучити",
    "Transfer" : "Передати",
    "Delete list" : "Вилучити список",
    "Add a new card" : "Додати нову картку",
    "Edit" : "Редагувати",
    "Add a new tag" : "Додати нову позначку",
    "title and color value must be provided" : "потрібно зазначити назву та колір",
    "Board name" : "Назва дошки",
    "Members" : "Учасники",
    "Upload new files" : "Додати файл",
    "Share from Files" : "Відкрити Файли",
    "Add this attachment" : "Долучити вкладення",
    "Show in Files" : "Показати в Файлах",
    "Download" : "Звантажити",
    "Delete Attachment" : "Забрати вкладення",
    "Restore Attachment" : "Відновити вкладення",
    "File to share" : "Виберіть файл для надання доступу",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Attachments" : "Вкладення",
    "Comments" : "Коментарі",
    "Modified" : "Змінено",
    "Created" : "Створено",
    "No comments yet. Begin the discussion!" : "Коментарів немає, почніть обговорення!",
    "Assign a tag to this card…" : "Додати позначку до цієї картки",
    "Assign to users" : "Призначити користувачам",
    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
    "Assign a user to this card…" : "Призначити користувачеві цю картку",
    "Due date" : "Протягом",
    "Set a due date" : "Встановити дату завершення",
    "Remove due date" : "Вилучити до",
    "Select Date" : "Вкажіть дату",
    "Today" : "Сьогодні",
    "Tomorrow" : "Завтра",
    "Next week" : "Наступний тиждень",
    "Next month" : "Наступний місяць",
    "Save" : "Зберегти",
    "In reply to" : "У відповідь",
    "Cancel reply" : "Скасувати відповідь",
    "Reply" : "Відповісти",
    "Update" : "Оновлення",
    "Description" : "Опис",
    "(Unsaved)" : "(Не збережено)",
    "(Saving…)" : "(Зберігання...)",
    "Formatting help" : "Допомога",
    "Edit description" : "Редагувати опис",
    "View description" : "Переглянути опис",
    "Add Attachment" : "Долучити вкладення",
    "Write a description …" : "Додайте опис ...",
    "Choose attachment" : "Вибрати вкладення",
    "(group)" : "(група)",
    "Todo items" : "Пункти завдань",
    "Edit card title" : "Редагувати заголовок картки",
    "Assign to me" : "Призначити мені",
    "Move card" : "Пересунути картку",
    "Card details" : "Деталі картки",
    "Unarchive card" : "Розархівувати картку",
    "Archive card" : "Архівувати картку",
    "Delete card" : "Вилучити картку",
    "Move card to another board" : "Перемістити картку до іншої дошки",
    "seconds ago" : "секунд тому",
    "All boards" : "Усі дошки",
    "Archived boards" : "Архівні дошки",
    "Shared with you" : "Вам надано доступ",
    "Deck settings" : "Налаштування колоди",
    "Use bigger card view" : "Режим перегляду зі збільшеними картками",
    "Show boards in calendar/tasks" : "Показувати дошки в календарі та завданнях",
    "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Створення власних робочих дощок користувачам, які не входять у задані групи, буде заблоковано. Проте, такі користувачі зможуть продовжити працювати зі спільними дошками, до яких у них є доступ.",
    "Board details" : "Деталі дошки",
    "Edit board" : "Редагувати дошку",
    "Clone board" : "Копіювати дошку",
    "Unarchive board" : "Розархівувати дошку",
    "Archive board" : "Архівувати дошку",
    "Turn on due date reminders" : "Нагадування про термін виконання",
    "Turn off due date reminders" : "Вимкнути нагадування про терміни виконання",
    "Due date reminders" : "Нагадування про терміни виконання",
    "No notifications" : "Немає сповіщень",
    "Delete board" : "Вилучити дошку",
    "Board {0} deleted" : "Дошку {0} вилучено",
    "No reminder" : "Відсутні нагадування",
    "An error occurred" : "Виникла помилка",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Ви впевнені, що хочете вилучити дошку {title}? Це призведе до видалення всіх даних цієї дошки, включаючи архівні картки.",
    "Delete the board?" : "Вилучити дошку?",
    "No due" : "Без призначеної дати",
    "No upcoming cards" : "Немає майбутніх завдань",
    "upcoming cards" : "очікують на виконання",
    "Due on {date}" : "До {date}",
    "Link to a board" : "Прив'язати до дошки",
    "Link to a card" : "Прив'язати до картки",
    "Message from {author} in {conversationName}" : "Повідомлення від {author} у {conversationName}",
    "Something went wrong" : "От халепа!",
    "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
    "Error creating the share" : "Помилка створення спільного доступу",
    "Share" : "Спільний доступ",
    "Add a new list" : "Додати новий список"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
